
"use client"
import React from "react";
import { useQuery } from "@tanstack/react-query";
import User from "../_types/accountNo";
import axios, { AxiosError } from "axios";
import { notifications } from "@mantine/notifications";


async function queryUser() {
    let user: User | null = null;
    
    try {
        const response = await axios.get<User>('/api/user');
        user = response.data;
    } catch (error: AxiosError | any) {
        console.log(error);
        notifications.show({
            color: 'red',
            title: error.code,
            message: error.message
        })
    }
    return user;
}

const UserContext = React.createContext<User | null | undefined>(undefined);

function UserContextProvider({ children }: { children: React.ReactNode }) {

    const userQuery = useQuery({
        queryKey: ['user'],
        queryFn: queryUser,
        networkMode: 'always',
    });

    return (
        <UserContext.Provider value={userQuery.data}>
            {children}
        </UserContext.Provider>
    )
}

const UserContextConsumer = UserContext.Consumer;

export { UserContext, UserContextProvider, UserContextConsumer }