import AppDataSource from "@/app/_data/source/app-data-source";
import { getIronSession } from "iron-session";
import SessionPayload from "../auth/session/payload";
import { cookies } from "next/headers";
import getSessionOptions from "../auth/session/options";
import { User } from "@/app/_data/entities/User";
import { generateOTP } from "./generate_otp";

export async function GET(req: Request) {

    try {
        const session = await getIronSession<SessionPayload>(cookies(), getSessionOptions())
        const connection = await AppDataSource.getConnection();
        const userRepo = connection.getRepository(User);

        if(!session.accountNo){
            return Response.json({ message:`Please sign in before get OTP`})
        }

        const user_mob_no = await userRepo.createQueryBuilder('user')
            .select(['mobile_number'])
            .where("user.bank_account_no = :AccountNo", { AccountNo: session.accountNo})
            .getRawOne();

        const mobileNumber = user_mob_no.mobile_number
        if(mobileNumber === null )
            return Response.json({ message: "Mobile number is not updated.Please contact with administrator"},{status:404})

        // const otp = generateOTP(5)
        const otp = "199812"; //For demo
        session.otp= parseInt(otp);
        session.expiryTime=Date.now() + 90 * 1000;
        
        await session.save();
        //console.log(session);
        const maskedPartMobNo= 'x'.repeat(mobileNumber.toString().length -3);
        const lastThreeDigit= mobileNumber.toString().slice(-3);
        console.log( "OTP :" , otp);
        return Response.json({ message:`New OTP has been sent to your register mobile number ${maskedPartMobNo + lastThreeDigit}-KCCB`})

    } 
    catch (error) {
        console.error(error);
        return Response.json(null, { status: 500 })
    }
}


export async function POST(req: Request) {

    try {

        const session = await getIronSession<SessionPayload>(cookies(), getSessionOptions())
        const body = await req.json();
        const { OTP} = body;

        if(!session.accountNo){
            return Response.json({ message:`Please sign in before get OTP`})
        }

        if (!OTP ||  OTP === '' || Number.isNaN(OTP))
            return Response.json({ message: "OTP field can not be blank" })

        console.log(session)
        // Check for OTP expiry time
        if(Date.now()> session.expiryTime){ 
            session.otp =NaN;
            session.expiryTime=NaN;
            await session.save();
        }
        //console.log(session);
        if(Number.isNaN(session.otp))
            return Response.json({ error: "The OTP Session has timed out "},{status:401})

        if(session.otp !== parseInt(OTP))
            return Response.json({ error: "Please enter valid OTP."},{status:401})
        
        session.TwoStepAuthentication = true;
        await session.save();
        //console.log(session);
        return Response.json({ ok: true })
    } 
    catch (error) 
    {
        console.error(error);
        return Response.json(null, { status: 500 })
    }
}