import { getIronSession } from "iron-session";
import { cookies } from "next/headers";
import getSessionOptions from "../auth/session/options";
import SessionPayload from "../auth/session/payload";
import AppDataSource from "@/app/_data/source/app-data-source";
import { Ticket } from "@/app/_data/entities/Ticket";
import { User } from "@/app/_data/entities/User";


export async function POST(request: Request) {
  try {
    const session = await getIronSession<SessionPayload>(
      cookies(),
      getSessionOptions()
    );
    if (!session.accountNo) {
      return Response.json({ message: `Please sign in before raise a ticket` })
    }

    if (!session.TwoStepAuthentication) {
      return Response.json(null);
    }
    //console.log(new  Date().toLocaleString("en-IN"));
    const URL = "http://localhost/crm_internal/api/rest/issues/";
    const body = await request.json();
    //request_category, nature_of_request, issue, message 
    const { summary, description, additional_information, steps_to_reproduce } = body;
    const project = { id: 1 };
    const requestBody = { ...body, project };
    const result = await (await fetch(URL, {
      method: "POST",
      headers:
        { "Content-Type": "application/json", "Authorization": "M7xHFMiZcg_oPrGZoRY-kPoivoniK3BO" },
      body: JSON.stringify(requestBody)
    }))
    if (result.status === 403) {
      return Response.json({ message: 'Invalid Token' }, { status: 403 })
    }
    if (result.status === 400) {
      return Response.json({ message: 'Project not specified' }, { status: 400 })
    }
    if (result.status === 404) {
      return Response.json({ message: 'Project not found' }, { status: 404 })
    }
    if (result.status === 429) {
      return Response.json({ message: 'Please raised ticket after sometime.' }, { status: 429 })
    }

    ///CRM database management 
    const connection_crm = await AppDataSource.getConnection();
    const userRepo = connection_crm.getRepository(User);
    const user_table = await userRepo.createQueryBuilder('user')
      .select(['first_name', 'middle_name', 'last_name'])
      .where("user.bank_account_no = :AccountNo", { AccountNo: session.accountNo })
      .getRawOne();

    const user_name = (user_table.first_name ? user_table.first_name + ' ' : '') +
      (user_table.middle_name ? user_table.middle_name + ' ' : '') +
      (user_table.last_name ? user_table.last_name + ' ' : '');
      
    const ticketRepo = connection_crm.getRepository(Ticket);
    const ticket = new Ticket();
    ticket.category_of_request = summary;
    ticket.nature_of_request = description;
    ticket.additional_info = additional_information
    ticket.message = steps_to_reproduce;
    ticket.created_by = user_name;
    //ticket.created_date = new Date().toString();
    ticket.created_date=new  Date().toLocaleString("en-IN");

    await ticketRepo.save(ticket);
    return Response.json({ message: `Ticket No:${result.statusText} created successfully` })
  }
  catch (error) {
    console.error(error);
    return Response.json(null, { status: 500 });
  }
}


export async function GET(request: Request) {
  try {
    const session = await getIronSession<SessionPayload>(cookies(), getSessionOptions());
    if (!session.TwoStepAuthentication) {
      return Response.json(null);
    }

    if (!session.accountNo) {
      return Response.json({ message: `Please sign in before raise a ticket` })
    }

    const connection_crm = await AppDataSource.getConnection();
    const connection_mantis = await AppDataSource.getMantisConnection();
    const userRepo = connection_crm.getRepository(User);
    const user_table = await userRepo.createQueryBuilder('user')
      .select(['first_name', 'middle_name', 'last_name'])
      .where("user.bank_account_no = :AccountNo", { AccountNo: session.accountNo })
      .getRawOne();

    const user_name = (user_table.first_name ? user_table.first_name + ' ' : '') +
      (user_table.middle_name ? user_table.middle_name + ' ' : '') +
      (user_table.last_name ? user_table.last_name + ' ' : '');
    
    const ticketRepo = connection_crm.getRepository(Ticket);
    const ticket_list = await ticketRepo.createQueryBuilder('ticket')
      .select(['id', 'category_of_request', 'nature_of_request', 'created_date','additional_info'])
      .where("ticket.created_by = :created_by", { created_by: user_name }).getRawMany();
  
    if(!ticket_list){return Response.json('No Details Found')}
    const ticket_ids = ticket_list.map(ticket => ticket.id);
    // Mantis-database fetching for "status" & "message"
    const queryRunner = connection_mantis.createQueryRunner();
    await queryRunner.connect();
    let ticketResolution: { [key: number]: string } = {};
    let ticketMessage: { [key: number]: string[] } = {};

    for (const id of ticket_ids) {
      // For status of ticket
      const ticket_resolution = await queryRunner.query('SELECT resolution,handler_id FROM "kccb_bug" WHERE id = $1', [id]);
      const ticket_status =ticket_resolution[0]?.resolution
      const ticket_handler =ticket_resolution[0]?.handler_id
      let status :string ='';
      if(ticket_status === 10 && ticket_handler === 0){status = 'Open'}
      if(ticket_handler > 0){status = 'In Progress'}
      if(ticket_status === 20){status='Resolved'}
      if(ticket_status === 30){status='Reopen'}
      ticketResolution[id] = status   

      // For Message of ticket
      const ticket_note = await queryRunner.query('SELECT id FROM "kccb_bugnote" WHERE bug_id = $1', [id]);
      const ticket_note_ids =ticket_note.map((item:{id:number}) =>item.id)

      for(const note_id of ticket_note_ids ){
        const ticket_note_text = await queryRunner.query('SELECT note FROM "kccb_bugnote_text" WHERE id = $1', [note_id]);
        if (!ticketMessage[id]) {
          ticketMessage[id] = [];
        }
        ticketMessage[id].push(...ticket_note_text);
      }
    }
  const result = ticket_list.map(item =>
  (
    {
      ...item,status:ticketResolution[item.id]||null,message: ticketMessage[item.id]||null
    }
  )
  )
  queryRunner.release();
  return Response.json(result)
  }
  catch (error) {
    console.error(error);
    return Response.json(null, { status: 500 });
  }
}

