import { getIronSession } from "iron-session";
import { cookies } from "next/headers";
import getSessionOptions from "../auth/session/options";
import SessionPayload from "../auth/session/payload";
import AppDataSource from "@/app/_data/source/app-data-source";
import { User } from "@/app/_data/entities/User";


export async function GET(request: Request) {
  try {
    const session = await getIronSession<SessionPayload>(
      cookies(),
      getSessionOptions()
    );
    if (!session.accountNo) {
      return Response.json(null);
    }

    const connection = await AppDataSource.getConnection();
    const userRepo = connection.getRepository(User);

    let user_details = await userRepo
      .createQueryBuilder("user")
      .select(["id","bank_account_no"])
      .where("user.bank_account_no = :userAccountNo", { userAccountNo: session.accountNo })
      .getRawOne();

    //console.log(session)
    // if (!user_details || session.TwoStepAuthentication === false)
    if (!user_details)
      return Response.json({ message: "User_details not found" }, { status: 404 });

    return Response.json(user_details);
  } catch (error) {
    console.error(error);
    return Response.json(null, { status: 500 });
  }
}

