"use client";

import { notifications } from "@mantine/notifications";
import axios, { AxiosError } from "axios";
import React, { useState } from "react";

const ComplaintForm: React.FC = () => {
  const [category, setCategory] = useState("");
  const [description, setDescription] = useState("");
  const [additionalFields, setAdditionalFields] = useState<string[]>([]);
  const [additionalFieldValues, setAdditionalFieldValues] = useState<Record<string, string>>({});
  const [message, setMessage] = useState("");

  const handleCategoryChange = (e: React.ChangeEvent<HTMLSelectElement>) => {
    const selectedCategory = e.target.value;
    setCategory(selectedCategory);
    setDescription(""); // Reset description when category changes
    setAdditionalFields([]);
    setAdditionalFieldValues({});
  };

  const handleDescriptionClick = () => {
    if (!category) {
      alert("Please select the Category of Complaint first.");
    }
  };

  const handleDescriptionChange = (e: React.ChangeEvent<HTMLSelectElement>) => {
    if (!category) {
      setDescription(""); // Prevent changing description without category
      return;
    }

    const selectedDescription = e.target.value;
    setDescription(selectedDescription);

    // Add additional fields for specific descriptions
    if (selectedDescription === "Transaction Issue") {
      setAdditionalFields([
        "Debit Card",
        "Transaction Amount",
        "Transaction Reference Number  ",
        "Transaction Date",
        "ATM ID/Terminal ID",
      ]);
    }
    else if(selectedDescription === "Fund Transfer failure"){
      setAdditionalFields([
        "Transaction Amount",
        "Transaction ID/Transaction Reference Number",
        "Transaction Date"
      ]);
    } 
    else {
      setAdditionalFields([]);
    }
  };

  const handleAdditionalFieldChange = (field: string, value: string) => {
    if(field === "Transaction Amount" && isNaN(Number(value)))
    {
      alert ('Please enter a valid number');
      return;
    }
    if(field === "Debit Card" && isNaN(Number(value)))
      {
        alert ('Please Enter Valid Debit Card Number');
        return;
      }
    setAdditionalFieldValues((prevValues) => ({
      ...prevValues,
      [field]: value,
    }));
  };

  async function handleSubmit(e: React.FormEvent) {
    e.preventDefault();
    for (const field of additionalFields) {
      if (!additionalFieldValues[field]) {
        alert(`Please fill in the ${field}`);
        return;
      }
    }
    if (!message.trim()) {
      alert("Message field is required.");
      return;
    }
    
    const additionalInformation: string[] = [];
    if (additionalFieldValues['ATM ID/Terminal ID']) {
      additionalInformation.push(`ATM ID: ${additionalFieldValues['ATM ID/Terminal ID']}`);
    }
    if (additionalFieldValues['Debit Card']) {
      additionalInformation.push(`Debit Card: ${additionalFieldValues['Debit Card']}`);
    }
    if (additionalFieldValues['Transaction Amount']) {
      additionalInformation.push(`Transaction Amount: ${additionalFieldValues['Transaction Amount']}`);
    }
    if (additionalFieldValues['Transaction Reference Number  ']) {
      additionalInformation.push(`Transaction Reference Number  : ${additionalFieldValues['Transaction Reference Number  ']}`);
    }
    if (additionalFieldValues['Transaction Date']) {
      additionalInformation.push(`Transaction Date: ${additionalFieldValues['Transaction Date']}`);
    }
    if(additionalFieldValues['Transaction ID/Transaction Reference Number']){
      additionalInformation.push(`Transaction ID/Transaction Reference Number: ${additionalFieldValues['Transaction ID/Transaction Reference Number']}`);
    }

    const requestBody = {
      summary: description,
      description: description,
      additional_information: additionalInformation.join(", "),
      steps_to_reproduce: message,
    };

    try {
      const response = await axios.post("/api/ticket", requestBody);
      const data = await response.data;
      console.log('API response:', data);
      alert(data.message);
      window.location.reload();
    }
    catch (error: AxiosError | any) {
      notifications.show({
        color: 'red',
        title: error.response.status,
        message: error.response.data.message

      })
    }
  }

  return (
    <div style={{ padding: "20px", maxWidth: "500px", textAlign: "left" }}>
      <form onSubmit={handleSubmit}>
        <h2 style={{ marginBottom: "8px" }}> Create New Ticket </h2>

        <label style={{ marginTop: "8px" }}>
          Category of Complaint <span style={{ color: "red" }}>*</span>
          <select
            value={category}
            onChange={handleCategoryChange}
            required
            style={{ display: "block", marginBottom: "10px", width: "100%" }}
          >
            <option value="" disabled>
              Select Category
            </option>
            <option value="ATM">ATM Related</option>
            <option value="IB">Internet Banking</option>
            <option value="MB">Mobile Banking</option>
            <option value="Others">Others</option>
          </select>
        </label>

        <label>
          Description <span style={{ color: "red" }}>*</span>
          <select
            value={description}
            onClick={handleDescriptionClick}
            onChange={handleDescriptionChange}
            required
            style={{ display: "block", marginBottom: "10px", width: "100%" }}
          >
            <option value="" disabled>
              Select Description
            </option>
            {category === "ATM" && <option value="Transaction Issue">Transaction Issue</option>}
            {category === "UPI" && <option value="UPI Issue">UPI Issue</option>}
            {category === "IB" && (
              <>
                {/* <option value="IMPS">IMPS Funds Transfer</option> */}
                <option value="Fund Transfer failure">Fund Transfer Failure</option>
                <option value="Network Issue">Network Issue</option>
              </>
            )}
            {category === "MB" && (
              <>
                {/* <option value="IMPS">IMPS Funds Transfer</option> */}
                <option value="Fund Transfer failure">Fund Transfer Failure</option>
                <option value="Network Issue">Network Issue</option>
              </>
            )}
            {category === "Others" && (
              <>
                {/* <option value="IMPS">IMPS Funds Transfer</option> */}
                <option value="Others">Others</option>
              </>
            )}
          </select>
        </label>
        
        {additionalFields.map((field, index) => (
          <div key={index}>
            {field === "Transaction Date" ? (
              <label>
                {field}: <span style={{ color: "red" }}>*</span>
                <input
                  type="date"
                  value={additionalFieldValues[field] || ""}
                  onChange={(e) => handleAdditionalFieldChange(field, e.target.value)}
                  required
                  style={{
                    display: "block",
                    marginBottom: "10px",
                    width: "100%",
                  }}
                />
              </label>
            ) : (
              <label>
                {field}: <span style={{ color: "red" }}>*</span>
                <input
                  type="text"
                  placeholder={`Enter ${field}`}
                  value={additionalFieldValues[field] || ""}
                  onChange={(e) => handleAdditionalFieldChange(field, e.target.value)}
                  required
                  style={{
                    display: "block",
                    marginBottom: "10px",
                    width: "100%",
                  }}
                />
              </label>
            )}
          </div>
        ))}
        <label>
          Message (Max 500 characters) <span style={{ color: "red" }}>*</span>
          <textarea
            value={message}
            onChange={(e) => setMessage(e.target.value)}
            maxLength={500}
            rows={5}
            required
            style={{
              display: "block",
              marginBottom: "10px",
              width: "100%",
              resize: "none",
            }}
          />
        </label>

        <button
          type="submit"
          style={{
            display: "block",
            width: "100%",
            padding: "10px",
            backgroundColor: "#4CAF50",
            color: "white",
            border: "none",
            cursor: "pointer",
          }}
        >
          Submit
        </button>
      </form>
    </div>
  );
};

export default ComplaintForm;
