"use client"

import classes from './page.module.css';
import React, { useContext, useState } from "react";
import { TextInput, Button, Container, Title, Image, SimpleGrid, LoadingOverlay, Avatar, Paper, Text } from "@mantine/core";
import image from './helpdesk.png';
import { useForm, SubmitHandler } from "react-hook-form";
import axios, { AxiosError } from "axios";
import { notifications, showNotification } from "@mantine/notifications";
import { useMutation, useQueryClient } from "@tanstack/react-query";
import { useDisclosure } from "@mantine/hooks";


type SendAccNoInput = {
  AccNo: string
}

type Result = {
  ok?: boolean
  message?: string
}
async function handleRequestOTP(SendAccNoInput: SendAccNoInput) {
  
  let Result: Result = { ok: false }
  try {
    const response = await axios.post("/api/auth/login/account_no", SendAccNoInput);
    if (response.data.ok) {
      const otp_response = await axios.get("/api/otp");
      if (otp_response.status === 200) {
          // redirect('/otp');
        window.location.href = 'login/otp'
      }
    }
    Object.assign(Result, response.data);
  } catch (error: AxiosError | any) {
    console.log(error);
    notifications.show({
      color: 'red',
      title: error.response.status,
      message: error.response.data.message
    })
  }
  return Result;
}

export default function sendOTP() {

  const queryClient = useQueryClient();
  const { register, handleSubmit, formState: { errors } } = useForm<SendAccNoInput>()
  const sendOTPMutation = useMutation<Result, AxiosError, SendAccNoInput>({
    mutationKey: ['sendOtp'],
    mutationFn: handleRequestOTP,
  })
  const onSubmit: SubmitHandler<SendAccNoInput> = async (SendAccNoInput) => {
    const Result = await sendOTPMutation.mutateAsync(SendAccNoInput);
    if (Result.ok)
      await queryClient.refetchQueries({ queryKey: ['OTP'] });
  }
  const [opened, { open, close }] = useDisclosure(false);
  return (
    <Container className={classes.root}>
      <SimpleGrid spacing={{ base: 40, sm: 80 }} cols={{ base: 1, sm: 2 }}>
        <Image src={image.src} className={classes.mobileImage} />
        <div>
          <LoadingOverlay visible={sendOTPMutation.isPending || sendOTPMutation.data?.ok} />

          <Paper component='form' className={classes.form} radius={0} p={30} onSubmit={handleSubmit(onSubmit)}>
            <Avatar
              src="https://encrypted-tbn0.gstatic.com/images?q=tbn:ANd9GcR-ZljkQXsXUP1-EwnIPZtVq_JWhwGUW7b0_eSMno-bag&s"
              alt="Jacob Warnhalter"
              radius="xxxl"
            />
            <Title order={2} className={classes.title} ta="center" mt="md" mb={50}>
              Customer Request Management
            </Title>
            <TextInput label="Customer Account Number *"
              placeholder="e.g. 1234"
              size="md"
              {...register('AccNo', { required: true })} />
            {errors.AccNo && <Text c='red'>*Required</Text>}
            <Button fullWidth mt="xl" size="md" type='submit' >
              Send OTP
            </Button>
            {sendOTPMutation.data?.message &&
              <Text c='red' ta='center' pt={30}>{sendOTPMutation.data.message}</Text>}
          </Paper>

        </div>
        <Image src={image.src} className={classes.desktopImage} />
      </SimpleGrid>
      <footer justify-content='center' color='green'>Copyright © 2025 Tata Consultancy Services, All rights reserved.</footer>
    </Container>
  );
}

